darkhistory.spec.spectools — DarkHistory documentation

# darkhistory.spec.spectools

Functions useful for processing spectral data.

Functions

`discretize`(eng, func_dNdE, *args) | Discretizes a continuous function.
`engloss_rebin_fast`(in_eng, eng, grid_vals, …) | Fast energy loss rebin.
`get_bin_bound`(eng) | Returns the bin boundary of an abscissa.
`get_bounds_between`(eng, E1[, E2, bound_type]) | Returns the bin boundary of an abscissa between two energies.
`get_indx`(eng, E) | Returns index of bin containing E.
`get_log_bin_width`(eng) | Return the log bin width of the abscissa.
`get_normalized_spec`(spec, dE_dVdt, rs) | Normalizes the spectrum to per baryon per dlnz, given dE/(dV dt).
`rebin_N_arr`(N_arr, in_eng[, out_eng, …]) | Rebins an array of particle number with fixed energy.

Classes

`EnglossRebinData`(in_eng, engloss_arr, final_eng) | Structure for energy loss rebinning data.

#### Previous topic

darkhistory.spec.pppc.get_pppc_spec

#### Next topic

darkhistory.spec.spectools.discretize

### This Page

Show Source